@@ -1,4 +1,6 @@
 package Mojolicious::Plugin::ToolkitRenderer;
+# ABSTRACT: Template Toolkit Renderer Mojolicious Plugin
+
 use strict;
 use warnings;
 
@@ -6,7 +8,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Mojo::Exception;
 use Template ();
 
-our $VERSION = '1.02';
+our $VERSION = '1.04'; # VERSION
 
 sub register {
     my ( $self, $app, $settings ) = @_;
@@ -65,12 +67,25 @@ sub register {
 
 1;
 
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Mojolicious::Plugin::ToolkitRenderer - Template Toolkit Renderer Mojolicious Plugin
 
+=head1 VERSION
+
+version 1.04
+
+=for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Mojolicious-Plugin-ToolkitRenderer.svg)](https://travis-ci.org/gryphonshafer/Mojolicious-Plugin-ToolkitRenderer)
+[![Coverage Status](https://coveralls.io/repos/gryphonshafer/Mojolicious-Plugin-ToolkitRenderer/badge.png)](https://coveralls.io/r/gryphonshafer/Mojolicious-Plugin-ToolkitRenderer)
+
+=for test_synopsis my($self);
+
 =head1 SYNOPSIS
 
     # Mojolicious
@@ -84,7 +99,7 @@ Mojolicious::Plugin::ToolkitRenderer - Template Toolkit Renderer Mojolicious Plu
             config => {
                 RELATIVE  => 1,
                 EVAL_PERL => 0,
-                FILTERS   => { ucfirst => sub { return ucfirst shift },
+                FILTERS   => { ucfirst => sub { return ucfirst shift } },
                 ENCODING  => 'utf8',
             },
             context => sub {
@@ -95,7 +110,7 @@ Mojolicious::Plugin::ToolkitRenderer - Template Toolkit Renderer Mojolicious Plu
     $self->renderer->default_handler('tt');
 
     # Mojolicious::Lite
-    plugin ToolkitRenderer => {
+    plugin( ToolkitRenderer => {
         settings => {
             inline_template => 'inline',
             controller      => 'c',
@@ -103,13 +118,13 @@ Mojolicious::Plugin::ToolkitRenderer - Template Toolkit Renderer Mojolicious Plu
         config => {
             RELATIVE  => 1,
             EVAL_PERL => 0,
-            FILTERS   => { ucfirst => sub { return ucfirst shift },
+            FILTERS   => { ucfirst => sub { return ucfirst shift } },
             ENCODING  => 'utf8',
         },
         context => sub {
             shift->define_vmethod( 'scalar', 'upper', sub { return uc shift } );
         },
-    };
+    } );
 
 =head1 DESCRIPTION
 
@@ -184,15 +199,45 @@ require TT's context.
 
 L<Mojolicious>, L<Mojolicious::Plugin>, L<Template>.
 
+You can also look for additional information at:
+
+=over 4
+
+=item *
+
+L<GitHub|https://github.com/gryphonshafer/Mojolicious-Plugin-ToolkitRenderer>
+
+=item *
+
+L<CPAN|http://search.cpan.org/dist/Mojolicious-Plugin-ToolkitRenderer>
+
+=item *
+
+L<MetaCPAN|https://metacpan.org/pod/Mojolicious::Plugin::ToolkitRenderer>
+
+=item *
+
+L<AnnoCPAN|http://annocpan.org/dist/Mojolicious-Plugin-ToolkitRenderer>
+
+=item *
+
+L<Travis CI|https://travis-ci.org/gryphonshafer/Mojolicious-Plugin-ToolkitRenderer>
+
+=item *
+
+L<Coveralls|https://coveralls.io/r/gryphonshafer/Mojolicious-Plugin-ToolkitRenderer>
+
+=back
+
 =head1 AUTHOR
 
-Gryphon Shafer E<lt>gryphon@cpan.orgE<gt>.
+Gryphon Shafer <gryphon@cpan.org>
 
-    code('Perl') || die;
+=head1 COPYRIGHT AND LICENSE
 
-=head1 LICENSE
+This software is copyright (c) 2015 by Gryphon Shafer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
